open.20.fsguruh@xoxy.net 63e2ae60a5 now does rescaling on 256base instead of 100; removes a lot of division by a shift right 8
Needs testing!!! Volunteer please come in. 
Benefits of change:
-248 bytes code generated used gcc 4.7.2
-huge performance increase. My measurements:
   simple mix goes down from 2,87msec to 1.93msec
   middle complex mix goes down from 3,37msec to 2,00msec
   complex mix (with phase change) goes down from 6,87msec to 4,18msec
2013-02-18 20:26:16 +00:00
2012-11-15 02:10:48 +00:00
2012-05-07 18:35:48 +00:00
2012-04-21 17:52:06 +00:00
S
Description
No description provided
GPL-2.0
400 MiB
Languages
C 71.9%
C++ 25.4%
Python 0.9%
CMake 0.6%
Shell 0.3%
Other 0.7%